@@ -331,7 +331,8 @@ def beams_to_bintable(beams):
     c1 = Column(name='BMAJ', format='1E', array=[bm.major.to(u.arcsec).value for bm in beams], unit=u.arcsec.to_string('FITS'))
     c2 = Column(name='BMIN', format='1E', array=[bm.minor.to(u.arcsec).value for bm in beams], unit=u.arcsec.to_string('FITS'))
     c3 = Column(name='BPA', format='1E', array=[bm.pa.to(u.deg).value for bm in beams], unit=u.deg.to_string('FITS'))
-    c4 = Column(name='CHAN', format='1J', array=[bm.meta['CHAN'] if 'CHAN' in bm.meta else 0 for bm in beams])
+    #c4 = Column(name='CHAN', format='1J', array=[bm.meta['CHAN'] if 'CHAN' in bm.meta else 0 for bm in beams])
+    c4 = Column(name='CHAN', format='1J', array=np.arange(len(beams)))
     c5 = Column(name='POL', format='1J', array=[bm.meta['POL'] if 'POL' in bm.meta else 0 for bm in beams])
 
     bmhdu = BinTableHDU.from_columns([c1, c2, c3, c4, c5])
@@ -361,31 +362,6 @@ def beam_props(beams, includemask=None):
     return major, minor, pa
 
 
-def average_beams(beams, includemask=None, raise_for_nan=True):
-    """
-    Average the beam major, minor, and PA attributes.
-
-    This is usually a dumb thing to do!
-    """
-
-    from radio_beam import Beam
-    from astropy.stats import circmean
-
-    major, minor, pa = beam_props(beams, includemask)
-
-    if raise_for_nan and (np.any(np.isnan(major)) or np.any(np.isnan(minor)) or
-                          np.any(np.isnan(pa))):
-        raise ValueError("Some beam parameters are NaN.  Try masking out the bad beams.")
-
-    new_beam = Beam(major=major.mean(), minor=minor.mean(),
-                    pa=circmean(pa, weights=major/minor))
-
-    if raise_for_nan and np.any(np.isnan(new_beam)):
-        raise ValueError("NaNs after averaging.  This is a bug.")
-
-    return new_beam
-
-
 def largest_beam(beams, includemask=None):
     """
     Returns the largest beam (by area) in a list of beams.
