@@ -81,30 +81,14 @@ class LowerDimensionalObject(u.Quantity, BaseNDClass):
         if format is None:
             format = determine_format(filename)
         if format == 'fits':
-            self.hdu.writeto(filename, clobber=overwrite)
+            try:
+                self.hdu.writeto(filename, overwrite=overwrite)
+            except TypeError:
+                self.hdu.writeto(filename, clobber=overwrite)
         else:
             raise ValueError("Unknown format '{0}' - the only available "
                              "format at this time is 'fits'")
 
-    def to(self, unit, equivalencies=[]):
-        """
-        Return a new `~spectral_cube.lower_dimensional_structures.LowerDimensionalObject` of the same class with the
-        specified unit.
-
-        See `astropy.units.Quantity.to` for further details.
-        """
-        converted_array = u.Quantity.to(self, unit,
-                                        equivalencies=equivalencies).value
-
-        # use private versions of variables, not the generated property
-        # versions
-        # Not entirely sure the use of __class__ here is kosher, but we do want
-        # self.__class__, not super()
-        new = self.__class__(value=converted_array, unit=unit, copy=True,
-                             wcs=self._wcs, meta=self._meta, mask=self._mask,
-                             header=self._header)
-
-        return new
 
     def __getslice__(self, start, end, increment=None):
         # I don't know why this is needed, but apparently one of the inherited
@@ -189,6 +173,61 @@ class LowerDimensionalObject(u.Quantity, BaseNDClass):
         """
         return u.Quantity(self)
 
+    def to(self, unit, equivalencies=[], freq=None):
+        """
+        Return a new `~spectral_cube.lower_dimensional_structures.Projection`
+        of the same class with the specified unit.
+
+        See `astropy.units.Quantity.to` for further details.
+        """
+
+        if not isinstance(unit, u.Unit):
+            unit = u.Unit(unit)
+
+        if unit == self.unit:
+            # No copying
+            return self
+
+        if self.unit.is_equivalent(u.Jy / u.beam):
+            # replace "beam" with the actual beam
+            if not hasattr(self, 'beam'):
+                raise ValueError("To convert objects with Jy/beam units, "
+                                 "the object needs to have a beam defined.")
+            brightness_unit = self.unit * u.beam
+
+            # create a beam equivalency for brightness temperature
+            if freq is None:
+                try:
+                    freq = self.with_spectral_unit(u.Hz).spectral_axis
+                except AttributeError:
+                    raise TypeError("Object of type {0} has no spectral "
+                                    "information. `freq` must be provided for"
+                                    " unit conversion from Jy/beam"
+                                    .format(type(self)))
+            else:
+                if not freq.unit.is_equivalent(u.Hz):
+                    raise u.UnitsError("freq must be given in equivalent "
+                                       "frequency units.")
+
+            bmequiv = self.beam.jtok_equiv(freq)
+            factor = brightness_unit.to(unit,
+                                        equivalencies=bmequiv + list(equivalencies))
+        else:
+            # scaling factor
+            factor = self.unit.to(unit, equivalencies=equivalencies)
+
+        converted_array = (self.quantity * factor).value
+
+        # use private versions of variables, not the generated property
+        # versions
+        # Not entirely sure the use of __class__ here is kosher, but we do want
+        # self.__class__, not super()
+        new = self.__class__(value=converted_array, unit=unit, copy=True,
+                             wcs=self._wcs, meta=self._meta, mask=self._mask,
+                             header=self._header)
+
+        return new
+
     @property
     def _mask(self):
         """ Annoying hack to deal with np.ma.core.is_mask failures (I don't
@@ -202,6 +241,16 @@ class LowerDimensionalObject(u.Quantity, BaseNDClass):
     def _mask(self, value):
         self.__mask = value
 
+    def shrink_mask(self):
+        """
+        Copy of the numpy masked_array shrink_mask method.  This is essentially
+        a hack needed for matplotlib to show images.
+        """
+        m = self._mask
+        if m.ndim and not m.any():
+            self._mask = nomask
+        return self
+
 class Projection(LowerDimensionalObject, SpatialCoordMixinClass):
 
     def __new__(cls, value, unit=None, dtype=None, copy=True, wcs=None,
@@ -481,6 +530,16 @@ class Projection(LowerDimensionalObject, SpatialCoordMixinClass):
 
         return self[slices]
 
+    def to(self, unit, equivalencies=[], freq=None):
+        """
+        Return a new `~spectral_cube.lower_dimensional_structures.Projection`
+        of the same class with the specified unit.
+
+        See `astropy.units.Quantity.to` for further details.
+        """
+
+        return super(Projection, self).to(unit, equivalencies, freq)
+
 # A slice is just like a projection in every way
 class Slice(Projection):
     pass
@@ -661,8 +720,17 @@ class OneDSpectrum(LowerDimensionalObject, MaskableArrayMixinClass,
         newheader['CUNIT1'] = unit.to_string(format='FITS')
         newheader['CDELT1'] *= wcs_cunit.to(unit)
 
+        if self._mask is not None:
+            newmask = self._mask.with_spectral_unit(unit,
+                                                    velocity_convention=velocity_convention,
+                                                    rest_value=rest_value)
+            newmask._wcs = newwcs
+        else:
+            newmask = None
+
         return self._new_spectrum_with(wcs=newwcs, spectral_unit=unit,
-                                       meta=newmeta, header=newheader)
+                                       mask=newmask, meta=newmeta,
+                                       header=newheader)
 
     def __getitem__(self, key, **kwargs):
         try:
@@ -831,6 +899,15 @@ class OneDSpectrum(LowerDimensionalObject, MaskableArrayMixinClass,
 
         return self._new_spectrum_with(data=newspec)
 
+    def to(self, unit, equivalencies=[]):
+        """
+        Return a new `~spectral_cube.lower_dimensional_structures.OneDSpectrum`
+        of the same class with the specified unit.
+        See `astropy.units.Quantity.to` for further details.
+        """
+
+        return super(OneDSpectrum, self).to(unit, equivalencies, freq=None)
+
     def with_fill_value(self, fill_value):
         """
         Create a new :class:`OneDSpectrum` with a different ``fill_value``.
