@@ -24,12 +24,16 @@ from ..spectral_cube import OneDSpectrum, Projection
 from ..np_compat import allbadtonan
 from .. import spectral_axis
 from .. import base_class
+from .. import utils
 
 from . import path
 from .helpers import assert_allclose, assert_array_equal
 
 # needed to test for warnings later
 warnings.simplefilter('always', UserWarning)
+warnings.simplefilter('error', utils.UnsupportedIterationStrategyWarning)
+warnings.simplefilter('error', utils.NotImplementedWarning)
+warnings.simplefilter('error', utils.WCSMismatchWarning)
 
 try:
     import scipy.ndimage
@@ -100,6 +104,11 @@ def test_huge_disallowed():
             cube + 5*cube.unit
         assert 'entire cube into memory' in exc.value.args[0]
 
+        with pytest.raises(ValueError) as exc:
+            cube.max(how='cube')
+        assert 'entire cube into memory' in exc.value.args[0]
+
+
         cube.allow_huge_operations = True
 
         # just make sure it doesn't fail
@@ -118,6 +127,15 @@ class BaseTest(object):
         self.mask = mask
         self.d = d
 
+class BaseTestMultiBeams(object):
+
+    def setup_method(self, method):
+        c, d = cube_and_raw('adv_beams.fits')
+        mask = BooleanArrayMask(d > 0.5, c._wcs)
+        c._mask = mask
+        self.c = c
+        self.mask = mask
+        self.d = d
 
 translist = [('advs', [0, 1, 2, 3]),
              ('dvsa', [2, 3, 0, 1]),
@@ -561,14 +579,17 @@ class TestNumpyMethods(BaseTest):
         assert not np.any(np.isnan(scpct.value))
         assert scpct.unit == self.c.unit
 
-    @pytest.mark.parametrize('method', ('sum', 'min', 'max',
-                             'median', 'argmin', 'argmax'))
+    @pytest.mark.parametrize('method', ('sum', 'min', 'max', 'std', 'mad_std',
+                                        'median', 'argmin', 'argmax'))
     def test_transpose(self, method):
         c1, d1 = cube_and_raw('adv.fits')
         c2, d2 = cube_and_raw('vad.fits')
         for axis in [None, 0, 1, 2]:
             assert_allclose(getattr(c1, method)(axis=axis),
                             getattr(c2, method)(axis=axis))
+            # check that all these accept progressbar kwargs
+            assert_allclose(getattr(c1, method)(axis=axis, progressbar=True),
+                            getattr(c2, method)(axis=axis, progressbar=True))
 
 
 class TestSlab(BaseTest):
@@ -613,6 +634,10 @@ class TestSlab(BaseTest):
         self.c.spectral_slab(-318600 * ms, -320000 * ms)
         assert list(self.c._wcs.wcs.crpix) == crpix
 
+class TestSlabMultiBeams(BaseTestMultiBeams, TestSlab):
+    """ same tests with multibeams """
+    pass
+
 
 class TestRepr(BaseTest):
 
@@ -621,7 +646,7 @@ class TestRepr(BaseTest):
 SpectralCube with shape=(4, 3, 2) and unit=K:
  n_x:      2  type_x: RA---SIN  unit_x: deg    range:    24.062698 deg:   24.063349 deg
  n_y:      3  type_y: DEC--SIN  unit_y: deg    range:    29.934094 deg:   29.935209 deg
- n_s:      4  type_s: VOPT      unit_s: m / s  range:  -321214.699 m / s: -317350.054 m / s
+ n_s:      4  type_s: VOPT      unit_s: km / s  range:     -321.215 km / s:    -317.350 km / s
         """.strip()
 
     def test_repr_withunit(self):
@@ -630,7 +655,7 @@ SpectralCube with shape=(4, 3, 2) and unit=K:
 SpectralCube with shape=(4, 3, 2) and unit=Jy:
  n_x:      2  type_x: RA---SIN  unit_x: deg    range:    24.062698 deg:   24.063349 deg
  n_y:      3  type_y: DEC--SIN  unit_y: deg    range:    29.934094 deg:   29.935209 deg
- n_s:      4  type_s: VOPT      unit_s: m / s  range:  -321214.699 m / s: -317350.054 m / s
+ n_s:      4  type_s: VOPT      unit_s: km / s  range:     -321.215 km / s:    -317.350 km / s
         """.strip()
 
 
@@ -925,16 +950,19 @@ def test_header_units_consistent():
 
     cube, data = cube_and_raw('advs.fits')
 
+    cube_ms = cube.with_spectral_unit(u.m/u.s)
     cube_kms = cube.with_spectral_unit(u.km/u.s)
     cube_Mms = cube.with_spectral_unit(u.Mm/u.s)
 
-    assert cube.header['CUNIT3'] == 'm s-1'
+    assert cube.header['CUNIT3'] == 'km s-1'
+    assert cube_ms.header['CUNIT3'] == 'm s-1'
     assert cube_kms.header['CUNIT3'] == 'km s-1'
     assert cube_Mms.header['CUNIT3'] == 'Mm s-1'
 
     # Wow, the tolerance here is really terrible...
-    assert_allclose(cube_Mms.header['CDELT3'], cube.header['CDELT3']/1e6,rtol=1e-3,atol=1e-5)
-    assert_allclose(cube.header['CDELT3']/1e3, cube_kms.header['CDELT3'],rtol=1e-2,atol=1e-5)
+    assert_allclose(cube_Mms.header['CDELT3'], cube.header['CDELT3']/1e3,rtol=1e-3,atol=1e-5)
+    assert_allclose(cube.header['CDELT3'], cube_kms.header['CDELT3'],rtol=1e-2,atol=1e-5)
+    assert_allclose(cube.header['CDELT3']*1e3, cube_ms.header['CDELT3'],rtol=1e-2,atol=1e-5)
 
     cube_freq = cube.with_spectral_unit(u.Hz)
 
@@ -1088,7 +1116,17 @@ def test_oned_slice_beams():
     assert hasattr(spec, 'beams')
     assert 'BMAJ' in spec.hdulist[1].data.names
 
-def test_oned_collapse():
+def test_subcube_slab_beams():
+    cube, data = cube_and_raw('sdav_beams.fits')
+
+    slcube = cube[1:]
+
+    assert all(slcube.hdulist[1].data['CHAN'] == np.arange(slcube.shape[0]))
+
+# collapsing to one dimension raywise doesn't make sense and is therefore
+# not supported.
+@pytest.mark.parametrize('how', ('auto', 'cube', 'slice'))
+def test_oned_collapse(how):
     # Check that an operation along the spatial dims returns an appropriate
     # spectrum
 
@@ -1096,7 +1134,7 @@ def test_oned_collapse():
     cube._meta['BUNIT'] = 'K'
     cube._unit = u.K
 
-    spec = cube.mean(axis=(1,2))
+    spec = cube.mean(axis=(1,2), how=how)
     assert isinstance(spec, OneDSpectrum)
     # data has a redundant 1st axis
     np.testing.assert_equal(spec.value, data.mean(axis=(0,2,3)))
@@ -1466,6 +1504,11 @@ def test_varyres_moment_logic_issue364():
 def test_mask_bad_beams():
     cube, data = cube_and_raw('vda_beams.fits')
 
+    # make sure all of the beams are initially good (finite)
+    assert np.all(cube._goodbeams_mask)
+    # make sure cropping the cube maintains the mask
+    assert np.all(cube[:3]._goodbeams_mask)
+
     # middle two beams have same area
     masked_cube = cube.mask_out_bad_beams(0.01,
                                           reference_beam=Beam(0.3*u.arcsec,
@@ -1473,6 +1516,7 @@ def test_mask_bad_beams():
                                                               60*u.deg))
 
     assert np.all(masked_cube.mask.include()[:,0,0] == [False,False,True,False])
+    assert np.all(masked_cube._goodbeams_mask == [False,False,True,False])
 
     mean = masked_cube.mean(axis=0)
     assert np.all(mean == cube[2,:,:])
@@ -1482,6 +1526,43 @@ def test_mask_bad_beams():
 
     mean2 = masked_cube2.mean(axis=0)
     assert np.all(mean2 == (cube[2,:,:]+cube[1,:,:])/2)
+    assert np.all(masked_cube2._goodbeams_mask == [False,True,True,False])
+
+def test_convolve_to_with_bad_beams():
+    cube, data = cube_and_raw('vda_beams.fits')
+
+    convolved = cube.convolve_to(Beam(0.5*u.arcsec))
+
+
+    with pytest.raises(ValueError) as exc:
+        # should not work: biggest beam is 0.4"
+        convolved = cube.convolve_to(Beam(0.35*u.arcsec))
+
+    assert exc.value.args[0] == "Beam could not be deconvolved"
+
+
+    # middle two beams are smaller than 0.4
+    masked_cube = cube.mask_channels([False, True, True, False])
+
+    # should work: biggest beam is 0.3 arcsec (major)
+    convolved = masked_cube.convolve_to(Beam(0.35*u.arcsec))
+
+    # this is a copout test; should really check for correctness...
+    assert np.all(np.isfinite(convolved.filled_data[1:3]))
+
+def test_jybeam_factors():
+    cube, data = cube_and_raw('vda_beams.fits')
+
+    assert_allclose(cube.jtok_factors(),
+                    [15111171.12641629, 10074201.06746361, 10074287.73828087,
+                     15111561.14508185])
+
+def test_channelmask_singlebeam():
+    cube, data = cube_and_raw('adv.fits')
+
+    masked_cube = cube.mask_channels([False, True, True, False])
+
+    assert np.all(masked_cube.mask.include()[:,0,0] == [False, True, True, False])
 
 def test_mad_std():
     cube, data = cube_and_raw('adv.fits')
@@ -1597,4 +1678,14 @@ def test_spectral_smooth_median():
     # Check first slice
     result = np.array([ 0.77513282,  0.35675333,  0.35675333,  0.98688694])
 
-    np.testing.assert_almost_equal(cube_spectral_median[:,1,1].value, result)
\ No newline at end of file
+    np.testing.assert_almost_equal(cube_spectral_median[:,1,1].value, result)
+
+def test_initialization_from_units():
+    """
+    Regression test for issue 447
+    """
+    cube, data = cube_and_raw('adv.fits')
+
+    newcube = SpectralCube(data=cube.filled_data[:], wcs=cube.wcs)
+
+    assert newcube.unit == cube.unit
