@@ -397,7 +397,8 @@ def strip_wcs_from_header(header):
             del newheader[kw]
 
     for kw in ('CRPIX{ii}', 'CRVAL{ii}', 'CDELT{ii}', 'CUNIT{ii}', 'CTYPE{ii}',
-               'PC0{ii}_0{jj}', 'CD{ii}_{jj}', 'CROTA{ii}'):
+               'PC0{ii}_0{jj}', 'CD{ii}_{jj}', 'CROTA{ii}', 'PC{ii}_{jj}',
+               'PV0{ii}_0{jj}', 'PV{ii}_{jj}'):
         for ii in range(5):
             for jj in range(5):
                 k = kw.format(ii=ii,jj=jj)
